@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:REFECO';    # AUTHORITY
-our $VERSION   = '0.003';          # VERSION
+our $VERSION   = '0.004';          # VERSION
 
 use Moose 2.2206;
 use namespace::clean;
@@ -63,6 +63,7 @@ sub configure {
         'CPANFile',
         'MetaJSON',
         'GithubMeta',
+        'MetaProvides::Package',
         'Prereqs::AuthorDeps',
         'Test::Compile',
         'Test::CheckDeps',
@@ -90,7 +91,7 @@ Dist::Zilla::PluginBundle::Author::REFECO - REFECO dists defaults
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 OVERVIEW
 
@@ -146,6 +147,7 @@ Reproducible by the following dist.ini config:
     [CPANFile]
     [MetaJSON]
     [GithubMeta]
+    [MetaProvides::Package]
     [Prereqs::AuthorDeps]
     [Test::Compile]
     [Test::CheckDeps]
